starcluster.progressbar.ReverseBar

Package starcluster :: Module progressbar :: Class ReverseBar |
[hide private]
[frames] | no frames]

# Class ReverseBar

source code

The reverse bar of progress, or bar of regress. :)

Instance Methods | [hide private]
update(self, pbar, width) Returns the string representing the widget. | source code
Inherited from `Bar`: `__init__` Inherited from `Bar` (private): `_format_marker` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, pbar, width) | source code
Returns the string representing the widget. The parameter pbar is a reference to the calling ProgressBar, where one can access attributes of the class for knowing how the update must be made. The parameter width is the total horizontal width the widget must have. At least this function must be overriden. Overrides: ProgressBarWidgetHFill.update (inherited documentation)